@@ -5,7 +5,7 @@ library(rly)
 
 context("Panic mode recovery test")
 
-Lexer <- R6Class("Lexer",
+Lexer <- R6::R6Class("Lexer",
   public = list(
     tokens = c('NAME','NUMBER', 
                'PLUS','MINUS','TIMES','DIVIDE','EQUALS', 
@@ -35,7 +35,7 @@ Lexer <- R6Class("Lexer",
   )
 )
 
-Parser <- R6Class("Parser",
+Parser <- R6::R6Class("Parser",
   public = list(
     tokens = Lexer$public_fields$tokens,
     # Parsing rules
